<?php

use Scriptor\Scriptor;
use Scriptor\Site;

/**
 * Function for rendering the navigation 
 * elements of the navigation bar.
 * 
 * @param array $options – Extra options to customize the rendering of the elements.
 *   - parent – (integer) (optional) Parent Page ID. Default value is '0' i.e. all pages with no parent.
 *   - maxLevel – (integer) (optional) The down-most level. Default is '1'.
 *   - sortBy – (string) (optional) The sort by page field or attribute. Default value position.
 *   - order – (string) (optional) Descending or ascending sort order. Default value 'asc'.
 *   - exclude – (array) (optional) An array of page ID's to be excluded from the navigation. Is empty by default.
 * 
 * @return string
 */
function render_navi_bar($options = [])
{
    $site = Scriptor::getSite();
    $navigation = '';
    $defaults = [
        'parent' => 0,
        'maxLevel' => 1,
        'exclude' => []
    ];
    $configs = array_merge($defaults, $options);
    $pageLevels = $site->getPageLevels($configs);

    if($pageLevels) {
        foreach($pageLevels[$configs['parent']] as $page) {
            if(in_array($page->id, $configs['exclude'])) continue;

            if(empty($pageLevels[$page->id])) {
                $navigation .= '<li><a href="'.$site->siteUrl.'/'.
                    Site::getPageUrl($page, $site->pages) .'">'.$page->name.'</a></li>';
            } else {
                $configs['parent'] = $page->id;
                $configs['maxLevel'] = $configs['maxLevel'] - 1;
                $navigation .= '<li><a href="#">'.$page->name.'</a>';
                $navigation .= '    <div class="uk-navbar-dropdown">';
                $navigation .= '        <ul class="uk-nav uk-navbar-dropdown-nav">';
                $navigation .= 				render_navi_bar($configs);		
                $navigation .= '        </ul>';
                $navigation .= '    </div>';
                $navigation .= '</li>';
            }
        }
    }
    return $navigation;
}

/**
 * Function for rendering the navigation 
 * elements of the offcanvas navigation.
 * 
 * @param array $options – Extra options to customize the rendering of the elements.
 *   - parent – (integer) (optional) Parent Page ID. Default value is '0' i.e. all pages with no parent.
 *   - maxLevel – (integer) (optional) The down-most level. Default is '1'.
 *   - sortBy – (string) (optional) The sort by page field or attribute. Default value position.
 *   - order – (string) (optional) Descending or ascending sort order. Default value 'asc'.
 *   - exclude – (array) (optional) An array of page ID's to be excluded from the navigation. Is empty by default.
 * 
 * @return string
 */
function render_offcanvas_navi($options = []) 
{
    $site = Scriptor::getSite();
    $navigation = '';
    $defaults = [
        'parent' => 0,
        'maxLevel' => 1,
        'exclude' => []
    ];
    $configs = array_merge($defaults, $options);
    $pageLevels = $site->getPageLevels($configs);

    if($pageLevels) {
        foreach($pageLevels[$configs['parent']] as $page) {
            if(in_array($page->id, $configs['exclude'])) continue;

            if(empty($pageLevels[$page->id])) {
                $navigation .= '<li><a href="'.$site->siteUrl.'/'.
                    Site::getPageUrl($page, $site->pages) .'">'.$page->name.'</a></li>';
            } else {
                $configs['parent'] = $page->id;
                $configs['maxLevel'] = $configs['maxLevel'] - 1;
                $navigation .= '<li class="uk-parent"><a href="#">'.$page->name.'</a>';
                $navigation .= '    <ul class="uk-nav-sub">';
                $navigation .= 		    render_navi_bar($configs);		
                $navigation .= '    </ul>';
                $navigation .= '</li>';
            }
        }
    }
    return $navigation;
}